require "spec_helper"

describe EventObject do
  using EventObject

  it "creates an array of events" do
    events = []
    listener   = lambda { :result }
    events.push listener
    events_with_arguments = []
    events_with_arguments.push lambda { |num| num+1 }

    expect(events.fire.last).to be(:result)
    expect(events.instance_fire(self).last).to be(:result)
    expect(events_with_arguments.fire(5).last).to be(6)

    events.off(listener)
    expect(events).to be_empty
  end

  it "fires NilClass methods" do
    expect(nil.fire).to eq([])
    expect(nil.instance_fire(self)).to eq([])
  end

  it "creates events and fires it" do
    emitter = EventEmitter.new
    emitter.on :success do
      18
    end
    emitter.on :success do
      42
    end

    expect(emitter.success!).to eq([18,42])
    expect(emitter.success.fire).to eq([18,42])
    expect(emitter.error).to be_empty
    expect(emitter.error.fire).to be_empty
  end

=begin
  DEPRECATED
  it "makes event chain" do
    emitter = EventEmitter.new
    emitter.on :data do |chunk|
      chunk + " world"
    end
    emitter.on :data do |chunk|
      chunk + "!!!"
    end

    data =  emitter.data.chain('Hello')

    expect(data).to eq('Hello world!!!')
  end
=end
end
