require "spec_helper"

describe EventObject do
  using EventObject

  class EventEmitter
    events :success, :error, :data
  end

  class ParentObject
    def ok
      'OK'
    end
  end


  # dup required in fires
  it "adds event to event" do
    emitter = EventEmitter.new
    counter = 0
    emitter.on :success do
      counter += 1
      emitter.on :success do
        counter += 1
      end
    end

    emitter.success!

    expect(counter).to be 1
  end

  it "adds instance method like listener to an event" do
    emitter = EventEmitter.new
    obj = ParentObject.new
    obj.listen(emitter, :success, :ok)
    expect(emitter.success!.last).to eq 'OK'

    emitter.off(:success, obj, :ok)
    expect(emitter.success!).to be_empty
  end

  it "stops listen event" do
    emitter = EventEmitter.new
    obj = ParentObject.new
    obj.listen(emitter, :success, :ok)
    expect(emitter.success!.last).to eq 'OK'

    obj.stop_listen(emitter, :success)
    expect(emitter.success!).to be_empty
  end

  it "defines singleton method" do
    expect {
      object = Object.new
      object.def :foo do
        1
      end
      expect(object.foo).to be 1
    }.to_not raise_error
  end
end
